# coding: utf-8

from qgis.core import *
from qgis.gui import *
from qgis.utils import iface

import sys
import re

def replace(match):
    if match.group(0): return match.group(0).lower()

@qgsfunction(args='auto', group='String', register=True)
def return_in_title (label, feature, parent):
    """
        Renvoie la chaine de caract&egrave;re suivant la charte toponymie de l'IGN (page 13)
        &rarr; <a href="http://www.ign.fr/sites/all/files/charte_toponymie_ign.pdf">http://www.ign.fr/sites/all/files/charte_toponymie_ign.pdf</a>
        <h4>Syntaxe</h4>
        <p>return_in_title(<i>name</i>)</p>
        <h4>Arguments</h4>
        <p><i>  name</i> &rarr; le nom de la ville &agrave; nettoyer.<br>  
        <h4>Exemple</h4>
        <p><!-- Exemple.-->
             return_in_title('AIX-EN-PROVENCE') &rarr; 'Aix-en-Provence'</p>
        
    """  
    try:
        newLabel = label.title()
    except AttributeError:
        parent.setEvalErrorString( u'String expected : {} must be a string'.format( label ) )
        return False
    newLabel = re.sub(u'(-|\s)(Au|Aux|De|Du|Devant|Derrière|En|La|Le|Les|Lès|Près|Sur|Sous)(-|\s)', replace, newLabel)
    newLabel = re.sub(u"[LD]\'", replace, newLabel)
    return newLabel
	
@qgsfunction(args='auto', group='String', register=True)
def bad_encoding (fieldname, feature, parent):
    """
        Renvoie vrai lorsqu'un caract&egrave;re  sp&eacute;cial est rep&eacute;r&eacute;
        <h4>Syntaxe</h4>
        <p>bad_encoding(<i>field</i>)</p>
        <h4>Arguments</h4>
        <p><i>  field</i> &rarr; le champs &agrave; v&eacute;rifier<br>  
        <h4>Exemple</h4>
        <p><!-- Exemple.-->
             bad_encoding("MY_FIELD") &rarr; True</p>
        
    """  
    try:
        if not fieldname:
            return False
        regex = re.compile(ur"[^a-z0-9àâçéèêëîïôûùüÿñæœ\'\"\’\,\(\)\-\–\_\.\:\;\,\s\«\»]", re.UNICODE | re.IGNORECASE)
        matche= regex.search(fieldname)
        return bool(matche)
    except AttributeError:
        parent.setEvalErrorString( u'{} does not exist'.format(fieldname))
        return False

